@@ -1,17 +1,16 @@
 package Datahub::Factory::Importer::Adlib;
 
-use strict;
-use warnings;
+use Datahub::Factory::Sane;
 
 use Moo;
 use Catmandu;
+use namespace::clean;
 
 with 'Datahub::Factory::Importer';
 
 has file_name => (is => 'ro', required => 1);
 has data_path => (is => 'ro', default => sub { return 'recordList.record.*'; });
 
-
 sub _build_importer {
     my $self = shift;
     my $importer = Catmandu->importer('XML', file => $self->file_name, data_path => $self->data_path);
@@ -19,6 +18,7 @@ sub _build_importer {
 }
 
 1;
+
 __END__
 
 =encoding utf-8
@@ -29,10 +29,10 @@ Datahub::Factory::Importer::Adlib - Import data from L<Adlib|http://www.adlibsof
 
 =head1 SYNOPSIS
 
-    use Datahub::Factory::Importer::Adlib;
+    use Datahub::Factory;
     use Data::Dumper qw(Dumper);
 
-    my $adlib = Datahub::Factory::Importer::Adlib->new(
+    my $adlib = Datahub::Factory->importer('Adlib')->new(
         file_name => '/tmp/export.xml',
         data_path => 'recordList.record.*'
     );
@@ -90,4 +90,4 @@ it under the same terms as Perl itself.
 L<Datahub::Factory>
 L<Catmandu>
 
-=cut
\ No newline at end of file
+=cut
